# more_click

<a href="https://pypi.org/project/more_click">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/more_click" />
</a>
<a href="https://pypi.org/project/more_click">
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/more_click" />
</a>
<a href="https://github.com/cthoyt/more_click/blob/main/LICENSE">
    <img alt="PyPI - License" src="https://img.shields.io/pypi/l/more_click" />
</a>
<a href="https://zenodo.org/badge/latestdoi/319609575">
    <img src="https://zenodo.org/badge/319609575.svg" alt="DOI">
</a>

Extra stuff for click I use in basically every repo
